@@ -1,5 +1,5 @@
 # ================= Sub-group Comparison of Effect Sizes ============
-#  meta.sub.cor
+#  meta.sub.cor =====================================================
 #' Confidence interval for a difference in average Pearson or partial 
 #' correlations for two sets of studies 
 #' 
@@ -29,7 +29,7 @@
 #' * Row 3 - estimate for difference, Set A - Set B
 #'
 #' The columns are:
-#' * Estimate - estimate of average correlation or difference
+#' * Estimate - estimated average correlation or difference
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -91,7 +91,7 @@ meta.sub.cor <- function(alpha, n, cor, s, group) {
 }
 
 
-#  meta.sub.spear
+#  meta.sub.spear =============================================
 #' Confidence interval for a difference in average Spearman 
 #' correlations for two sets of studies
 #' 
@@ -118,7 +118,7 @@ meta.sub.cor <- function(alpha, n, cor, s, group) {
 #' * Row 3 - estimate for difference, Set A - Set B
 #'
 #' The columns are:
-#' * Estimate - estimate of average correlation or difference
+#' * Estimate - estimated average correlation or difference
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -138,8 +138,7 @@ meta.sub.cor <- function(alpha, n, cor, s, group) {
 #' 
 #' 
 #' @references
-#' Bonett, D.G. (2008). Meta-analytic interval estimation for bivariate
-#' correlations. *Psychological Methods*, 13, 173-189.
+#' \insertRef{Bonett2008a}{vcmeta}
 #' 
 #' 
 #' @importFrom stats qnorm
@@ -181,7 +180,7 @@ meta.sub.spear <- function(alpha, n, cor, group) {
 }
 
 
-#  meta.sub.pbcor
+#  meta.sub.pbcor ===============================================
 #' Confidence interval for a difference in average point-biserial
 #' correlations for two sets of studies 
 #' 
@@ -191,10 +190,11 @@ meta.sub.spear <- function(alpha, n, cor, group) {
 #' difference in average point-biserial correlations for two mutually
 #' exclusive sets of studies. Each set can have one or more studies. Two 
 #' types of point-biserial correlations can be analyzed. One type uses
-#' an unweighted variance and is approrpaite for 2-group experimental
-#' designs. The other type uses a weighted variance and is appropriate
-#' for 2-group nonexperimental designs with simple random sampling. 
-#' Equality of variances within or across studies is not assumed.
+#' an unweighted variance and is recommended for 2-group experimental
+#' designs. The other type uses a weighted variance and is recommended
+#' for 2-group nonexperimental designs with simple random sampling (but
+#' not stratified random sampling) within each study. Equality of 
+#' variances within or across studies is not assumed.
 #'    
 #'    
 #' @param     alpha   	alpha level for 1-alpha confidence
@@ -220,7 +220,7 @@ meta.sub.spear <- function(alpha, n, cor, group) {
 #' * Row 3 - estimate for difference, Set A - Set B
 #'
 #' The columns are:
-#' * Estimate - estimate of average correlation or difference
+#' * Estimate - estimated average correlation or difference
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -306,7 +306,7 @@ meta.sub.pbcor <- function(alpha,  m1, m2, sd1, sd2, n1, n2, type, group) {
 }
 
 
-#  meta.sub.semipart
+#  meta.sub.semipart =========================================
 #' Confidence interval for a difference in average semipartial 
 #' correlations for two sets of studies 
 #' 
@@ -335,7 +335,7 @@ meta.sub.pbcor <- function(alpha,  m1, m2, sd1, sd2, n1, n2, type, group) {
 #' * Row 3 - estimate for difference, Set A - Set B
 #'
 #' The columns are:
-#' * Estimate - estimate of average correlation or difference
+#' * Estimate - estimated average correlation or difference
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -395,7 +395,7 @@ meta.sub.semipart <- function(alpha, n, cor, r2, group) {
 }
 
 
-#  meta.sub.cronbach
+#  meta.sub.cronbach ==============================================
 #' Confidence interval for a difference in average Cronbach 
 #' reliabilities for two sets of studies 
 #' 
@@ -425,7 +425,7 @@ meta.sub.semipart <- function(alpha, n, cor, r2, group) {
 #' * Row 3 - estimate for difference, Set A - Set B
 #'
 #' The columns are:
-#' * Estimate - estimate of average correlation or difference
+#' * Estimate - estimated average correlation or difference
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -489,8 +489,87 @@ meta.sub.cronbach <- function(alpha, n, rel, r, group) {
 }
 
 
-# ================= Linear Contrasts of Effect Sizes ============
-#  meta.lc.mean2
+#  meta.sub.gen ===============================================================
+#' Confidence interval for a difference in average effect size for two sets 
+#' of studies 
+#' 
+#' 
+#' @description
+#' Computes the estimate, standard error, and confidence interval for a 
+#' difference in the average effect size (any type of effect size) for
+#' two mutually exclusive sets of studies. Each set can have one or more 
+#' studies. All of the effects sizes should be compatible. 
+#'
+#'
+#' @param     alpha  	alpha level for 1-alpha confidence
+#' @param     est    	vector of estimated effect sizes 
+#' @param     se    	vector of effect size standard errors 
+#' @param     group  	vector of group indicators:
+#' * 1 for set A
+#' * 2 for set B
+#' * 0 to ignore
+#' 
+#'
+#' @return 
+#' Returns a matrix with three rows:
+#' * Row 1 - estimate for Set A
+#' * Row 2 - estimate for Set B
+#' * Row 3 - estimate for difference, Set A - Set B
+#'
+#' The columns are:
+#' * Estimate - estimated average effect size or difference
+#' * SE - standard error
+#' * LL - lower limit of the confidence interval
+#' * UL - upper limit of the confidence interval
+#' 
+#' 
+#' @examples
+#' est <- c(.920, .896, .760, .745)
+#' se <- c(.098, .075, .069, .055) 
+#' group <- c(1, 1, 2, 2)
+#' meta.sub.gen(.05, est, se, group)
+#' 
+#' # Should return:
+#' #                Estimate         SE          LL        UL
+#' # Set A:           0.9080 0.06170292 0.787064504 1.0289355
+#' # Set B:           0.7525 0.04411916 0.666028042 0.8389720
+#' # Set A - Set B:   0.1555 0.07585348 0.006829917 0.3041701
+#' 
+#' 
+#' @importFrom stats qnorm
+#' @export
+meta.sub.gen <- function(alpha, est, se, group) {
+  m <- length(est)
+  z <- qnorm(1 - alpha/2)
+  var <- se^2
+  g1 <- (group == rep(1, m))*1
+  g2 <- (group == rep(2, m))*1
+  m1 <- sum(g1)
+  m2 <- sum(g2)
+  ave.A <- sum(g1*est)/m1
+  se.ave.A <- sqrt(sum(g1*var)/m1^2)
+  ll.A <- ave.A - z*se.ave.A
+  ul.A <- ave.A + z*se.ave.A
+  ave.B <- sum(g2*est)/m2
+  se.ave.B <- sqrt(sum(g2*var)/m2^2)
+  ll.B <- ave.B - z*se.ave.B
+  ul.B <- ave.B + z*se.ave.B
+  diff <- ave.A - ave.B
+  se.diff <- sqrt(se.ave.A^2 + se.ave.B^2)
+  ll.diff <- diff - z*se.diff
+  ul.diff <- diff + z*se.diff
+  out1 <- t(c(ave.A, se.ave.A, ll.A, ul.A))
+  out2 <- t(c(ave.B, se.ave.B, ll.B, ul.B))
+  out3 <- t(c(diff, se.diff, ll.diff, ul.diff))
+  out <- rbind(out1, out2, out3)
+  colnames(out) <- c("Estimate", "SE", "LL", "UL")
+  rownames(out) <- c("Set A:", "Set B:", "Set A - Set B:")
+  return (out)
+}
+
+
+# ================= Linear Contrasts of Effect Sizes ================
+#  meta.lc.mean2 ====================================================
 #' Confidence interval for a linear contrast of mean differences from
 #' 2-group studies
 #'
@@ -514,7 +593,7 @@ meta.sub.cronbach <- function(alpha, n, rel, r, group) {
 #'
 #' @return 
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of the linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -565,7 +644,7 @@ meta.lc.mean2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, v) {
 }
 
 
-# meta.lc.stdmean2
+# meta.lc.stdmean2 ==================================================
 #' Confidence interval for a linear contrast of standardized mean 
 #' differences from 2-group studies  
 #' 
@@ -577,7 +656,7 @@ meta.lc.mean2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, v) {
 #' Use the square root average variance standardizer (stdzr = 0) for 2-group
 #' experimental designs.  Use the square root weighted variance standardizer
 #' (stdzr = 3) for 2-group nonexperimental designs with simple random sampling.
-#' The stdzr = 1 and stdzr = 2 options can be used with either 2-group experimental
+#' The stdzr = 1 and stdzr = 2 options can be used with either experimental
 #' or nonexperimental designs.
 #'
 #'
@@ -598,7 +677,7 @@ meta.lc.mean2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, v) {
 #' 
 #' @return 
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -669,7 +748,7 @@ meta.lc.stdmean2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, v, stdzr) {
 }
 
 
-#  meta.lc.mean.ps
+#  meta.lc.mean.ps ====================================================
 #' Confidence interval for a linear contrast of mean differences from 
 #' paired-samples studies 
 #' 
@@ -694,7 +773,7 @@ meta.lc.stdmean2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, v, stdzr) {
 #' 
 #' @return 
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -744,7 +823,7 @@ meta.lc.mean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, v) {
 }
 
 
-#  meta.lc.stdmean.ps
+#  meta.lc.stdmean.ps ===================================================
 #' Confidence interval for a linear contrast of standardized 
 #' mean differences from paired-samples studies 
 #' 
@@ -771,7 +850,7 @@ meta.lc.mean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, v) {
 #' 
 #' @return 
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -835,7 +914,7 @@ meta.lc.stdmean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, v, stdzr) {
 }
 
 
-#  meta.lc.meanratio2
+#  meta.lc.meanratio2 =================================================
 #' Confidence interval for a log-linear contrast of mean ratios from
 #' 2-group studies  	
 #' 
@@ -860,11 +939,11 @@ meta.lc.stdmean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, v, stdzr) {
 #' 
 #' @return 
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of log-linear contrast
+#' * Estimate - estimated log-linear contrast
 #' * SE - standard error of log-linear contrast
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
-#' * exp(Estimate) - the exponentiated estimate
+#' * exp(Estimate) - exponentiated log-linear contrast
 #' * exp(LL) - lower limit of the exponentiated confidence interval
 #' * exp(UL) - upper limit of the exponentiated confidence interval
 #' * df - degrees of freedom
@@ -920,7 +999,7 @@ meta.lc.meanratio2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, v) {
 }
 
 
-#  meta.lc.meanratio.ps
+#  meta.lc.meanratio.ps ================================================
 #' Confidence interval for a log-linear contrast of mean ratios from 
 #' paired-samples studies 
 #' 
@@ -945,11 +1024,11 @@ meta.lc.meanratio2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, v) {
 #' 
 #' @return
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of log-linear contrast
+#' * Estimate - estimatedf log-linear contrast
 #' * SE - standard error of log-linear contrast
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
-#' * exp(Estimate) -  exponentiated estimate of log-linear function
+#' * exp(Estimate) - exponentiated log-linear contrast
 #' * exp(LL) - lower limit of the exponentiated confidence interval
 #' * exp(UL) - upper limit of the exponentiated confidence interval
 #' * df - degrees of freedom
@@ -996,7 +1075,7 @@ meta.lc.meanratio.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, v) {
 }
 
 
-#  meta.lc.odds
+#  meta.lc.odds =====================================================
 #' Confidence interval for a log-linear contrast of odds ratios 
 #' 
 #' 
@@ -1015,9 +1094,9 @@ meta.lc.meanratio.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, v) {
 #' 
 #' @return 
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of log-linear contrast
+#' * Estimate - estimated log-linear contrast
 #' * SE - standard error of log-linear contrast
-#' * exp(Estimate) - the exponentiated contrast
+#' * exp(Estimate) - exponentiated log-linear contrast
 #' * exp(LL) - lower limit of the exponentiated confidence interval
 #' * exp(UL) - upper limit of the exponentiated confidence interval
 #' 
@@ -1060,7 +1139,7 @@ meta.lc.odds <- function(alpha, f1, f2, n1, n2, v) {
 }
 
 
-#  meta.lc.propratio2
+#  meta.lc.propratio2 =====================================================
 #' Confidence interval for a log-linear contrast of proportion ratios from 2-group studies
 #' 
 #' 
@@ -1079,9 +1158,9 @@ meta.lc.odds <- function(alpha, f1, f2, n1, n2, v) {
 #' 
 #' @return 
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of log-linear contrast
+#' * Estimate - estimated log-linear contrast
 #' * SE - standard error of log-linear contrast
-#' * exp(Estimate) - the exponentiated contrast
+#' * exp(Estimate) - exponentiated log-linear contrast
 #' * exp(LL) - lower limit of the exponentiated confidence interval
 #' * exp(UL) - upper limit of the exponentiated confidence interval
 #' 
@@ -1128,12 +1207,12 @@ meta.lc.propratio2 <- function(alpha, f1, f2, n1, n2, v) {
 } 
 
 
-#  meta.lc.prop2
+#  meta.lc.prop2 =============================================================
 #' Confidence interval for a linear contrast of proportion differences in 2-group studies 
 #' 
 #' 
 #' @description
-#' Computes the estimate, standard error, and confidence interval for a 
+#' Computes the estimate, standard error, and adjusted Wald confidence interval for a 
 #' linear contrast of 2-group proportion differences from two or more studies.
 #'
 #'
@@ -1147,10 +1226,10 @@ meta.lc.propratio2 <- function(alpha, f1, f2, n1, n2, v) {
 #'
 #' @return
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of the linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
-#' * LL - lower limit of the confidence interval
-#' * UL - upper limit of the confidence interval
+#' * LL - lower limit of the adjusted Wald confidence interval
+#' * UL - upper limit of the adjusted Wald confidence interval
 #' 
 #' 
 #' @examples
@@ -1193,15 +1272,15 @@ meta.lc.prop2 <- function(alpha, f1, f2, n1, n2, v) {
 }
 
 
-# meta.lc.prop.ps
+# meta.lc.prop.ps =======================================================
 #' Confidence interval for a linear contrast of proportion differences in 
 #' paired-samples studies 
 #' 
 #' 
 #' @description
-#' Computes the estimate, standard error, and confidence interval for a 
-#' linear contrast of paired-samples group proportion differences from two
-#' or more studies.
+#' Computes the estimate, standard error, and adjusted Wald confidence interval
+#' for a linear contrast of paired-samples proportion differences from two or
+#' more studies.
 #'
 #'
 #' @param     alpha  	alpha level for 1-alpha confidence
@@ -1214,10 +1293,10 @@ meta.lc.prop2 <- function(alpha, f1, f2, n1, n2, v) {
 #' 
 #' @return
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
-#' * LL - lower limit of the confidence interval
-#' * UL - upper limit of the confidence interval
+#' * LL - lower limit of the adjusted Wald confidence interval
+#' * UL - upper limit of the adjusted Wald confidence interval
 #' 
 #' 
 #' @examples
@@ -1259,15 +1338,15 @@ meta.lc.prop.ps <- function(alpha, f11, f12, f21, f22, v) {
 }
 
 
-#  meta.lc.agree
+#  meta.lc.agree ===================================================
 #' Confidence interval for a linear contrast of G-index coefficients  
 #' 
 #' 
 #' @description
-#' Computes the estimate, standard error, and confidence interval for a 
-#' linear contrast of G-index of agreement coefficients from two or more 
-#' studies. This function assumes that two raters each provide a dichotomous
-#' rating for a sample of objects.
+#' Computes the estimate, standard error, and adjusted Wald confidence 
+#' interval for a linear contrast of G-index of agreement coefficients 
+#' from two or more studies. This function assumes that two raters each
+#' provide a dichotomous rating for a sample of objects.
 #'
 #'
 #' @param     alpha  	alpha level for 1-alpha confidence
@@ -1279,10 +1358,10 @@ meta.lc.prop.ps <- function(alpha, f11, f12, f21, f22, v) {
 #' 
 #' @return
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
-#' * LL - lower limit of the confidence interval
-#' * UL - upper limit of the confidence interval
+#' * LL - lower limit of the adjusted Wald confidence interval
+#' * UL - upper limit of the adjusted Wald confidence interval
 #' 
 #' 
 #' @examples
@@ -1319,8 +1398,8 @@ meta.lc.agree <- function(alpha, f11, f12, f21, f22, v) {
 }
 
 
-# meta.lc.mean1
-#' Confidence interval a for a linear contrast of means
+# meta.lc.mean1 ===================================================
+#' Confidence interval for a linear contrast of means
 #' 
 #'
 #' @description
@@ -1342,7 +1421,7 @@ meta.lc.agree <- function(alpha, f11, f12, f21, f22, v) {
 #' 
 #' @return
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -1392,8 +1471,8 @@ meta.lc.mean1 <- function(alpha, m, sd, n, v, eqvar = FALSE) {
 }
 
 
-# meta.lc.prop1
-#' Confidence interval for a linear contrast of proportions. 
+# meta.lc.prop1 ==============================================
+#' Confidence interval for a linear contrast of proportions 
 #' 
 #' 
 #' @description
@@ -1409,7 +1488,7 @@ meta.lc.mean1 <- function(alpha, m, sd, n, v, eqvar = FALSE) {
 #'
 #' @return
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate -estimate of linear contrast
+#' * Estimate -estimated linear contrast
 #' * SE - standard error
 #' * LL - lower limit of the adjusted Wald confidence interval
 #' * UL - upper limit of the adjusted Wald confidence interval
@@ -1446,7 +1525,7 @@ meta.lc.prop1 <- function(alpha, f, n, v) {
 }
 
 
-#  meta.lc.gen
+#  meta.lc.gen =====================================================
 #' Confidence interval for a linear contrast of effect sizes 
 #' 
 #' 
@@ -1463,7 +1542,7 @@ meta.lc.prop1 <- function(alpha, f, n, v) {
 #' 
 #' @return
 #' Returns 1-row matrix with the following columns: 
-#' * Estimate - estimate of linear contrast
+#' * Estimate - estimated linear contrast
 #' * SE - standard error
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
