@@ -1,4 +1,4 @@
-# se.mean2 =========================================================
+# se.mean2 =================================================================
 #' Computes the standard error for a 2-group mean difference
 #' 
 #' 
@@ -11,6 +11,7 @@
 #' and \link[vcmeta]{meta.lm.gen} functions in applications where 
 #' compatible mean differences from a combination of 2-group
 #' and paired-samples experiments are used in the meta-analysis. 
+#' Equality of variances is not asumed.
 #' 
 #' 
 #' @param    m1		estimated mean for group 1 
@@ -23,7 +24,7 @@
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of mean difference
+#' * Estimate - estimated mean difference
 #' * SE - standard error
 #' 
 #'  
@@ -31,8 +32,8 @@
 #' se.mean2(21.9, 16.1, 3.82, 3.21, 40, 40)
 #'
 #  # Should return:
-#' #                  Estimate        SE
-#' # Mean difference:      5.8 0.7889312
+#' #                   Estimate        SE
+#' # Mean difference:       5.8 0.7889312
 #' 
 #' 
 #' @references
@@ -45,25 +46,26 @@ se.mean2 <- function(m1, m2, sd1, sd2, n1, n2) {
   se <- sqrt(sd1^2/n1 + sd2^2/n2)
   out <- t(c(d, se))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Mean difference:")
+  rownames(out) <- "Mean difference: "
   return(out)
 }
 
 
-# se.mean.ps =========================================================
+# se.mean.ps =================================================================
 #' Computes the standard error for a paired-samples mean difference
 #' 
 #' 
 #' @description
 #' This function can be used to compute the standard error of a 
 #' paired-samples mean difference using the estimated means, 
-#  estimated standard deviations, estimated Pearson correlation, 
+#' estimated standard deviations, estimated Pearson correlation, 
 #' and sample size. The effect size estimate and standard error 
 #' output from this function can be used as input in the
 #' \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, 
 #' and \link[vcmeta]{meta.lm.gen} functions in applications where 
 #' compatible mean differences from a combination of 2-group
 #' and paired-samples experiments are used in the meta-analysis. 
+#' Equality of variances is not assumed.
 #' 
 #' 
 #' @param    m1		estimated mean for measurement 1 
@@ -76,7 +78,7 @@ se.mean2 <- function(m1, m2, sd1, sd2, n1, n2) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of mean difference
+#' * Estimate - estimated mean difference
 #' * SE - standard error
 #' 
 #' 
@@ -84,8 +86,8 @@ se.mean2 <- function(m1, m2, sd1, sd2, n1, n2) {
 #' se.mean.ps(23.9, 25.1, 1.76, 2.01, .78, 25)
 #'
 #' # Should return:
-#' #                  Estimate        SE
-#' # Mean difference:     -1.2 0.2544833
+#' #                   Estimate        SE
+#' # Mean difference:      -1.2 0.2544833
 #' 
 #' @references
 #' \insertRef{Snedecor1980}{vcmeta}
@@ -97,12 +99,12 @@ se.mean.ps <- function(m1, m2, sd1, sd2, cor, n) {
   se <- sqrt((sd1^2 + sd2^2 - 2*cor*sd1*sd2)/n)
   out <- t(c(d, se))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Mean difference:")
+  rownames(out) <- "Mean difference: "
   return(out)
 }
 
 
-# se.stdmean2 =========================================================		
+# se.stdmean2 ================================================================		
 #' Computes the standard error for a 2-group standardized mean difference
 #' 
 #' 
@@ -119,7 +121,8 @@ se.mean.ps <- function(m1, m2, sd1, sd2, cor, n) {
 #' input in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen},
 #' and \link[vcmeta]{meta.lm.gen} functions in applications where compatible
 #' standardized mean differences from a combination of 2-group and 
-#' paired-samples experiments are used in the meta-analysis. 
+#' paired-samples experiments are used in the meta-analysis. Equality 
+#' of variances is not assumed.
 #'
 #' 
 #' @param    m1		  estimated mean for group 1 
@@ -137,7 +140,7 @@ se.mean.ps <- function(m1, m2, sd1, sd2, cor, n) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of standardized mean difference
+#' * Estimate - estimated standardized mean difference
 #' * SE - standard error
 #' 
 #' 
@@ -145,14 +148,17 @@ se.mean.ps <- function(m1, m2, sd1, sd2, cor, n) {
 #' se.stdmean2(21.9, 16.1, 3.82, 3.21, 40, 40, 0)
 #'
 #' # Should return: 
-#' #                               Estimate        SE
-#' # Standardized mean difference: 1.643894 0.2629049
+#' #                                Estimate        SE
+#' # Standardized mean difference:  1.643894 0.2629049
 #' 
 #' 
 #' @references
 #' \insertRef{Bonett2009a}{vcmeta}
 #'
 #'
+#' @seealso \link[vcmeta]{se.cohen}
+#'
+#'
 #' @export
 se.stdmean2 <- function(m1, m2, sd1, sd2, n1, n2, stdzr) {
   df1 <- n1 - 1
@@ -179,13 +185,14 @@ se.stdmean2 <- function(m1, m2, sd1, sd2, n1, n2, stdzr) {
   }
   out <- t(c(d, se))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Standardized mean difference:")
+  rownames(out) <- "Standardized mean difference: "
   return(out)
 }
 
 
-# se.stdmean.ps =========================================================		
-#' Computes the standard error for a paired-samples standardized mean difference
+# se.stdmean.ps ==============================================================	
+#' Computes the standard error for a paired-samples standardized mean 
+#' difference
 #' 
 #'
 #' @description
@@ -196,6 +203,7 @@ se.stdmean2 <- function(m1, m2, sd1, sd2, n1, n2, stdzr) {
 #' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
 #' applications where compatible standardized mean differences from a combination
 #' of 2-group and paired-samples experiments are used in the meta-analysis. 
+#' Equality of variances is not assumed.
 #' 
 #' 
 #' @param    m1		estimated mean for measurement 1 
@@ -211,7 +219,7 @@ se.stdmean2 <- function(m1, m2, sd1, sd2, n1, n2, stdzr) {
 #'  
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of standardized mean difference
+#' * Estimate - estimated standardized mean difference
 #' * SE - standard error
 #' 
 #' 
@@ -219,8 +227,8 @@ se.stdmean2 <- function(m1, m2, sd1, sd2, n1, n2, stdzr) {
 #' se.stdmean.ps(23.9, 25.1, 1.76, 2.01, .78, 25, 0)
 #'
 #' # Should return: 
-#' #                                  Estimate        SE
-#' # Standardizedd mean difference: -0.6352097 0.1602852
+#' #                                   Estimate        SE
+#' # Standardizedd mean difference:  -0.6352097 0.1602852
 #' 
 #' 
 #' @references
@@ -250,24 +258,23 @@ se.stdmean.ps <- function(m1, m2, sd1, sd2, cor, n, stdzr) {
   }
   out <- t(c(d, se))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Standardized mean difference:")
+  rownames(out) <- "Standardized mean difference: "
   return(out)
 }
 
 
-# se.cor =========================================================
+# se.cor ==========================================================
 #' Computes the standard error for a Pearson or partial correlation 
 #' 
 #'
 #' @description
 #' This function can be used to compute the standard error of a 
-#' Pearson or partial correlation using the estimatede correlation, 
-#' sample size, and number of control variables. The effect size 
-#' estimate and standard error output from this function can be used 
-#' as input in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen},
-#' and \link[vcmeta]{meta.lm.gen} functions in applications where a 
-#' combination of different types of correlations are used in the
-#' meta-analysis. 
+#' Pearson or partial correlation using the estimated correlation, 
+#' sample size, and number of control variables. The correlation, 
+#' along with the standard error output from this function, can be used 
+#' as input in the \link[vcmeta]{meta.ave.gen} function in applications
+#' where a combination of different types of correlations are used in
+#' the meta-analysis. 
 #' 
 #' 
 #' @param    cor	estimated Pearson or partial correlation  
@@ -277,7 +284,7 @@ se.stdmean.ps <- function(m1, m2, sd1, sd2, cor, n, stdzr) {
 #'   
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of Pearson or partial correlation
+#' * Estimate - Pearson or partial correlation (from input)
 #' * SE - standard error
 #' 
 #' 
@@ -285,8 +292,8 @@ se.stdmean.ps <- function(m1, m2, sd1, sd2, cor, n, stdzr) {
 #' se.cor(.40, 0, 55)
 #'
 #' # Should return: 
-#' #              Estimate       SE
-#' # Correlation:      0.4 0.116487
+#' #               Estimate       SE
+#' # Correlation:       0.4 0.116487
 #' 
 #' 
 #' @references
@@ -298,22 +305,22 @@ se.cor <- function(cor, s, n) {
   se.cor <- sqrt((1 - cor^2)^2/(n - 3 - s))
   out <- t(c(cor, se.cor))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Correlation:")
+  rownames(out) <- "Correlation: "
   return(out)
 }
 
 
-# se.spear =========================================================
+# se.spear ===================================================================
 #' Computes the standard error for a Spearman correlation 
 #' 
 #' 
 #' @description
-#' This function can be used to compute the standard error of a 
-#' Spearman correlation using the estimated correlation and sample 
-#' size. The standard error from this function can be used as input 
-#' in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, and
-#' \link[vcmeta]{meta.lm.gen} functions in applications where a combination
-#' of different types of correlations are used in the meta-analysis. 
+#' This function can be used to compute the Bonett-Wright standard
+#' error of a Spearman correlation using the estimated correlation
+#' and sample size. The standard error from this function can be used
+#' as input in the \link[vcmeta]{meta.ave.gen} function in applications 
+#' where a combination of different types of correlations are used in 
+#' the meta-analysis. 
 #' 
 #' 
 #' @param    cor		estimated Spearman correlation  
@@ -322,7 +329,7 @@ se.cor <- function(cor, s, n) {
 #'   
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of Spearman correlation
+#' * Estimate - Spearman correlation (from input)
 #' * SE - standard error
 #' 
 #' 
@@ -343,12 +350,12 @@ se.spear <- function(cor, n) {
   se.cor <- sqrt((1 - cor^2)^2*(1 + cor^2/2)/(n - 3))
   out <- t(c(cor, se.cor))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Correlation:")
+  rownames(out) <- "Spearman correlation: "
   return(out)
 }
 
 
-# se.semipart =========================================================
+# se.semipart ================================================================
 #' Computes the standard error for a semipartial correlation 
 #' 
 #'
@@ -357,10 +364,9 @@ se.spear <- function(cor, n) {
 #' semipartial correlation using the estimated correlation, sample 
 #' size, and squared multiple correlation for the full model.
 #' The effect size estimate and standard error output from this 
-#' function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
-#' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions
-#' in applications where a combination of different types of correlations
-#' are used in the meta-analysis. 
+#' function can be used as input in the \link[vcmeta]{meta.ave.gen} 
+#' function in applications where a combination of different types
+#' of correlations are used in the meta-analysis. 
 #' 
 #' 
 #' @param    cor	estimated semipartial correlation  
@@ -370,7 +376,7 @@ se.spear <- function(cor, n) {
 #'   
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of semipartial correlation
+#' * Estimate - semipartial correlation (from input)
 #' * SE - standard error
 #' 
 #' 
@@ -378,8 +384,8 @@ se.spear <- function(cor, n) {
 #' se.semipartial(.40, .25, 60)
 #'
 #' # Should return: 
-#' #                          Estimate        SE
-#' # Semipartial correlation:      0.4 0.1063262
+#' #                           Estimate        SE
+#' # Semipartial correlation:       0.4 0.1063262
 #' 
 #' 
 #' @export
@@ -389,12 +395,12 @@ se.semipartial <- function(cor, r2, n) {
  se.cor <- sqrt(a/(n - 3))
  out <- t(c(cor, se.cor))
  colnames(out) <- c("Estimate", "SE")
- rownames(out) <- c("Semipartial correlation:")
+ rownames(out) <- "Semipartial correlation: "
  return(out)
 }
 
 
-# se.pbcor =========================================================
+# se.pbcor ==============================================================
 #' Computes the standard error for a point-biserial correlation 
 #' 
 #'
@@ -402,16 +408,17 @@ se.semipartial <- function(cor, r2, n) {
 #' This function computes a point-biserial correlation and its standard 
 #' error for two types of point-biserial correlations in 2-group designs
 #' using the estimated means, estimated standard deviations, and samples
-#' sizes. One type of point-biserial correlation uses an unweighted average
-#' of variances and is appropriate for 2-group experimental designs. The 
-#' other type of point-biserial correlation uses a weighted average of
-#' variances and is appropriate for 2-group nonexperimental designs with
-#' simple random sampling. This function is useful in a meta-analysis of
-#' compatible point-biserial correlations where some studies used a 2-group 
-#' experimental design and other studies used a 2-group nonexperimental 
-#' design. The effect size estimate and standard error output from this 
-#' function can  be used as input in the \link[vcmeta]{meta.ave.gen}, 
-#' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions.
+#' sizes. Equality of variances is not assumed. One type of point-biserial
+#' correlation uses an unweighted average of variances and is recommended
+#' for 2-group experimental designs. The other type of point-biserial 
+#' correlation uses a weighted average of variances and is recommended for
+#' 2-group nonexperimental designs with simple random sampling (but not 
+#' stratified random sampling). This function is useful in a meta-analysis
+#' of compatible point-biserial correlations where some studies used a 
+#' 2-group experimental design and other studies used a 2-group 
+#' nonexperimental design. The effect size estimate and standard error 
+#' output from this function can  be used as input in the
+#' \link[vcmeta]{meta.ave.gen} function.
 #'
 #' 
 #' @param    m1		estimated mean for group 1 
@@ -427,7 +434,7 @@ se.semipartial <- function(cor, r2, n) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of point-biserial correlation
+#' * Estimate - estimated point-biserial correlation
 #' * SE - standard error
 #' 
 #' 
@@ -435,8 +442,8 @@ se.semipartial <- function(cor, r2, n) {
 #' se.pbcor(21.9, 16.1, 3.82, 3.21, 40, 40, 1)
 #'
 #' #  Should return: 
-#' #                               Estimate         SE
-#' #  Point-biserial correlation: 0.6349786 0.05981325
+#' #                                Estimate         SE
+#' #  Point-biserial correlation:  0.6349786 0.05981325
 #' 
 #' 
 #' @references
@@ -464,12 +471,12 @@ se.pbcor <- function(m1, m2, sd1, sd2, n1, n2, type) {
   }
   out <- t(c(cor, se.cor))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Point-biserial correlation:")
+  rownames(out) <- "Point-biserial correlation: "
   return(out)
 }
 
 
-# se.odds =========================================================
+# se.odds ====================================================================
 #' Computes the standard error for a log odds ratio 
 #' 
 #'
@@ -485,15 +492,15 @@ se.pbcor <- function(m1, m2, sd1, sd2, n1, n2, type) {
 #' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions.
 #' 
 #' 
-#' @param    f1		number of participants who have the outcome of interest in group 1 
-#' @param    f2		number of participants who have the outcome of interest in group 2   
+#' @param    f1		number of participants who have the outcome in group 1 
+#' @param    f2		number of participants who have the outcome in group 2   
 #' @param    n1		sample size for group 1
 #' @param    n2		sample size for group 2 
 #' 
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of log odds ratio
+#' * Estimate - estimated log odds ratio
 #' * SE - standard error
 #' 
 #' 
@@ -501,8 +508,8 @@ se.pbcor <- function(m1, m2, sd1, sd2, n1, n2, type) {
 #' se.odds(36, 50, 21, 50)
 #'
 #' # Should return: 
-#' #                 Estimate        SE
-#' # Log odds ratio: 1.239501 0.4204435
+#' #                  Estimate        SE
+#' # Log odds ratio:  1.239501 0.4204435
 #' 
 #' 
 #' @references
@@ -515,7 +522,7 @@ se.odds <- function(f1, n1, f2, n2) {
   se.log.OR <- sqrt(1/(f1 + .5) + 1/(f2 + .5) + 1/(n1 - f1 + .5) + 1/(n2 - f2 + .5))
   out <- t(c(log.OR, se.log.OR))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- "Log odds ratio:"
+  rownames(out) <- "Log odds ratio: "
   return(out)
 }
 
@@ -530,9 +537,9 @@ se.odds <- function(f1, n1, f2, n2) {
 #' deviations, and sample sizes. The log mean estimate and standard 
 #' error output from this function can be used as input in the
 #' \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, and
-#' link[vcmeta]{meta.lm.gen} functions in application where compatible
+#' \link[vcmeta]{meta.lm.gen} functions in application where compatible
 #' mean ratios from a combination of 2-group and paired-samples experiments
-#' are used in the meta-analysis.
+#' are used in the meta-analysis. Equality of variances is not assumed.
 #' 
 #' 
 #' @param    m1		estimated mean for group 1 
@@ -545,15 +552,15 @@ se.odds <- function(f1, n1, f2, n2) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of log mean ratio
+#' * Estimate - estimated log mean ratio
 #' * SE - standard error
 #'  
 #' @examples
 #' se.meanratio2(21.9, 16.1, 3.82, 3.21, 40, 40)
 #'
 #' # Should return:
-#' #                  Estimate       SE
-#' # Log mean ratio: 0.3076674 0.041886
+#' #                   Estimate       SE
+#' # Log mean ratio:  0.3076674 0.041886
 #' 
 #' 
 #' @references
@@ -568,24 +575,25 @@ se.meanratio2 <- function(m1, m2, sd1, sd2, n1, n2) {
   se <- sqrt(var1 + var2)
   out <- t(c(logratio, se))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- "Log mean ratio:"
+  rownames(out) <- "Log mean ratio: "
   return(out)
 }
 
 
-# se.meanratio.ps =========================================================
+# se.meanratio.ps =============================================================
 #' Computes the standard error for a paired-samples log mean ratio
 #' 
 #' 
 #' @description
 #' This function can be used to compute the standard error of a 
 #' paired-samples log mean ratio using the estimated means, estimated
-#  standard deviations, estimated Pearson correlation, and sample 
+#'  standard deviations, estimated Pearson correlation, and sample 
 #' size. The log-mean estimate and standard error output from
 #' this function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
 #' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
-#' application where compatible mean ratios from a combination of 2-group
+#' applications where compatible mean ratios from a combination of 2-group
 #' and paired-samples experiments are used in the meta-analysis. 
+#' Equality of variances is not assumed.
 #' 
 #' 
 #' @param    m1		estimated mean for measurement 1 
@@ -598,15 +606,15 @@ se.meanratio2 <- function(m1, m2, sd1, sd2, n1, n2) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of log mean ratio
+#' * Estimate - estimated log mean ratio
 #' * SE - standard error
 #'  
 #' @examples
 #' se.meanratio.ps(21.9, 16.1, 3.82, 3.21, .748, 40)
 #'
 #' # Should return:
-#' #                  Estimate         SE
-#' # Log mean ratio: 0.3076674 0.02130161
+#' #                   Estimate         SE
+#' # Log mean ratio:  0.3076674 0.02130161
 #' 
 #' 
 #' @references
@@ -622,21 +630,21 @@ se.meanratio.ps <- function(m1, m2, sd1, sd2, cor, n) {
  se <- sqrt(var1 + var2 - 2*cov)
  out <- t(c(logratio, se))
  colnames(out) <- c("Estimate", "SE")
- rownames(out) <- "Log mean ratio:"
+ rownames(out) <- "Log mean ratio: "
  return(out)
 }
 
 
-# se.slope =========================================================
+# se.slope =================================================================
 #' Computes a slope and standard error
 #' 
 #'
 #' @description 
 #' This function can be used to compute a slope and its standard error
 #' for a simple linear regression model (random-x model) using the estimated 
-#' Pearson correlation and the estimated standard deviations of response and 
-#' predictor variables. This function is useful in a meta-analysis of 
-#' slopes of a simple linear regression model where some studies report
+#' Pearson correlation and the estimated standard deviations of the 
+#' response and predictor variables. This function is useful in a meta-analysis
+#' of slopes of a simple linear regression model where some studies report
 #' the Pearson correlation but not the slope.
 #' 
 #'
@@ -647,7 +655,7 @@ se.meanratio.ps <- function(m1, m2, sd1, sd2, cor, n) {
 #'   
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of slope
+#' * Estimate - estimated slope
 #' * SE - standard error
 #' 
 #' 
@@ -655,8 +663,8 @@ se.meanratio.ps <- function(m1, m2, sd1, sd2, cor, n) {
 #' se.slope(.392, 4.54, 2.89, 60)
 #'
 #' # Should return: 
-#' #         Estimate        SE
-#' # Slope: 0.6158062 0.1897647
+#' #          Estimate        SE
+#' # Slope:  0.6158062 0.1897647
 #' 
 #' 
 #' @references
@@ -669,21 +677,21 @@ se.slope <- function(cor, sdy, sdx, n) {
   se.slope <- sqrt((sdy^2*(1 - cor^2)*(n - 1))/(sdx^2*(n - 1)*(n - 2)))
   out <- t(c(slope, se.slope))
   colnames(out) <- c("Estimate", "SE")
-  rownames(out) <- c("Slope:")
+  rownames(out) <- "Slope: "
   return(out)
 }
 
 
-# se.prop2 ========================================================= 
-#' Computes the Agresti-Caffo estimate and standard error for a 2-group
-#' proportion difference
+# se.prop2 =================================================================== 
+#' Computes the estimate and standard error for a 2-group proportion 
+#' difference
 #' 
 #' 
 #' @description
-#' This function can be used to compute the standard error of a 
-#' 2-group proportion difference using the frequency counts and sample
-#' sizes. The effect size estimate and standard error output from this
-#' function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
+#' This function can be used to compute the Agresti-Caffo standard 
+#' error of a 2-group proportion difference using the frequency 
+#' counts and sample sizes. The effect size estimate and standard 
+#' error output from this function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
 #' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
 #' applications where compatible proportion differences from a combination of 
 #' 2-group and paired-samples studies are used in the meta-analysis. 
@@ -697,7 +705,7 @@ se.slope <- function(cor, sdy, sdx, n) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of proportion difference
+#' * Estimate - estimated proportion difference
 #' * SE - standard error
 #' 
 #'  
@@ -705,8 +713,8 @@ se.slope <- function(cor, sdy, sdx, n) {
 #' se.prop2(31, 16, 40, 40)
 #'
 #' # Should return:
-#' #                         Estimate        SE
-#' # Proportion difference: 0.3571429 0.1002777
+#' #                          Estimate        SE
+#' # Proportion difference:  0.3571429 0.1002777
 #' 
 #' 
 #' @references
@@ -721,21 +729,21 @@ se.prop2 <- function(f1, f2, n1, n2) {
  se <- sqrt(p1*(1 - p1)/(n1 + 2) + p2*(1 - p2)/(n2 + 2))
  out <- t(c(est, se))
  colnames(out) <- c("Estimate", "SE")
- rownames(out) <- c("Proportion difference:")
+ rownames(out) <- "Proportion difference: "
  return(out)
 }
 
 
-# se.prop.ps =========================================================
-#' Computes the Bonett-Price estimate and standard error for a 
-#' paired-samples proportion difference
+# se.prop.ps ==============================================================
+#' Computes the estimate and standard error for a paired-samples
+#' proportion difference
 #' 
 #' 
 #' @description
-#' This function can be used to compute the standard error of a 
-#' paired-samples proportion difference using the frequency counts from a 
-#' 2 x 2 contingency table. The effect size estimate and standard error
-#' output from this function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
+#' This function can be used to compute the Bonett-Price standard error 
+#' of a paired-samples proportion difference using the frequency counts 
+#' from a 2 x 2 contingency table. The effect size estimate and standard 
+#' error output from this function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
 #' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
 #' applications where compatible proportion differences from a combination of
 #' 2-group and paired-samples studies are used in the meta-analysis. 
@@ -749,7 +757,7 @@ se.prop2 <- function(f1, f2, n1, n2) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of proportion difference
+#' * Estimate - estimated proportion difference
 #' * SE - standard error
 #' 
 #'  
@@ -757,8 +765,8 @@ se.prop2 <- function(f1, f2, n1, n2) {
 #' se.prop.ps(16, 64, 5, 15)
 #'
 #' # Should return:
-#' #                         Estimate         SE
-#' # Proportion difference: 0.5784314 0.05953213
+#' #                          Estimate         SE
+#' # Proportion difference:  0.5784314 0.05953213
 #' 
 #' 
 #' @references
@@ -774,7 +782,7 @@ se.prop.ps <- function(f00, f01, f10, f11) {
  se <- sqrt(((p01 + p10) - (p01 - p10)^2)/(n + 2))
  out <- t(c(est, se))
  colnames(out) <- c("Estimate", "SE")
- rownames(out) <- c("Proportion difference:")
+ rownames(out) <- "Proportion difference: "
  return(out)
 }
 
@@ -795,7 +803,8 @@ se.prop.ps <- function(f00, f01, f10, f11) {
 #' \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, and 
 #' \link[vcmeta]{meta.lm.gen} functions in a meta-analysis where some studies
 #' have used one of the two parallel response variables and other studies have
-#' used the other parallel response variable. 
+#' used the other parallel response variable. Equality of variances is not
+#' assumed.
 #' 
 #' 
 #' @param    m1A	   estimated mean for variable A in group 1 
@@ -813,7 +822,7 @@ se.prop.ps <- function(f00, f01, f10, f11) {
 #' 
 #' @return
 #' Returns a one-row matrix:
-#' * Estimate - estimate of average mean difference
+#' * Estimate - estimated average mean difference
 #' * SE - standard error 
 #' * VAR(A) - variance of mean difference for variable A
 #' * VAR(B) - variance of mean difference for variable B
@@ -824,8 +833,8 @@ se.prop.ps <- function(f00, f01, f10, f11) {
 #' se.ave.mean2.dep(21.9, 16.1, 3.82, 3.21, 24.8, 17.1, 3.57, 3.64, .785, 40, 40)
 #'
 #' # Should return:
-#' #      Estimate        SE    VAR(A)    VAR(B)  COV(A,B)
-#' # [1,]     6.75 0.7526878 0.6224125 0.6498625 0.4969403
+#' #                          Estimate        SE    VAR(A)    VAR(B)  COV(A,B)
+#' # Average mean difference:     6.75 0.7526878 0.6224125 0.6498625 0.4969403
 #' 
 #' 
 #' @export
@@ -839,6 +848,7 @@ se.ave.mean2.dep <- function(m1A, m2A, sd1A, sd2A, m1B, m2B, sd1B, sd2B, rAB, n1
   se <- sqrt((v1 + v2 + 2*cov)/4)
   out <- t(c(est, se, v1, v2, cov))
   colnames(out) <- c("Estimate", "SE", "VAR(A)", "VAR(B)", "COV(A,B)")
+  rownames(out) <- "Average mean difference: "
   return(out)
 }
 
@@ -880,9 +890,9 @@ se.ave.mean2.dep <- function(m1A, m2A, sd1A, sd2A, m1B, m2B, sd1B, sd2B, rAB, n1
 #' se.ave.cor.over(.462, .518, .755, 100)
 #'
 #' # Should return:
-#' #               Estimate         SE  VAR(cor12) VAR(cor13) COV(cor12,cor13)
-#' # Correlation  0.4900000 0.07087351 0.006378045 0.00551907      0.004097553
-#' # Fisher       0.5360603 0.09326690 0.010309278 0.01030928      0.007119936
+#' #                Estimate         SE  VAR(cor12) VAR(cor13) COV(cor12,cor13)
+#' # Correlation:  0.4900000 0.07087351 0.006378045 0.00551907      0.004097553
+#' # Fisher:       0.5360603 0.09326690 0.010309278 0.01030928      0.007119936
 #'
 #'
 #' @export
@@ -901,7 +911,7 @@ se.ave.cor.over <- function(cor12, cor13, cor23, n) {
   out2 <- t(c(est2, se2, v1.z, v2.z, cov2))
   out <- rbind(out1, out2)
   colnames(out) <- c("Estimate", "SE", "VAR(cor12)", "VAR(cor13)", "COV(cor12,cor13)")
-  rownames(out) <- c("Correlation", "Fisher")
+  rownames(out) <- c("Correlation: ", "Fisher: ")
   return(out)
 }
 
@@ -913,9 +923,9 @@ se.ave.cor.over <- function(cor12, cor13, cor23, n) {
 #' 
 #' @description
 #' In a study that reports the sample size and six correlations (cor12, cor34,
-#' (cor13, cor14, cor23, and cor24) where variables 1 and 3 are different 
-#' measurements of the same attribute and variables 2 and 4 are different 
-#' measurements of the same attribute, this function can be used to compute the 
+#' cor13, cor14, cor23, and cor24) where variables 1 and 3 are different 
+#' measurements of one attribute and variables 2 and 4 are different 
+#' measurements of a second attribute, this function can be used to compute the 
 #' average of cor12 and cor34 and its standard error. Note that cor12 and cor34
 #' have no variable in common (i.e., no "overlapping" variable). The average 
 #' correlation and the standard error from this function can be used as 
@@ -947,9 +957,9 @@ se.ave.cor.over <- function(cor12, cor13, cor23, n) {
 #' se.ave.cor.nonover(.357, .398, .755, .331, .347, .821, 100)
 #'
 #' # Should return:
-#' #             Estimate         SE VAR(cor12)  VAR(cor34) COV(cor12,cor34)
-#' # Correlation 0.377500 0.07768887 0.00784892 0.007301895      0.004495714
-#' # Fisher      0.397141 0.09059993 0.01030928 0.010309278      0.006122153
+#' #               Estimate         SE VAR(cor12)  VAR(cor34) COV(cor12,cor34)
+#' # Correlation:  0.377500 0.07768887 0.00784892 0.007301895      0.004495714
+#' # Fisher:       0.397141 0.09059993 0.01030928 0.010309278      0.006122153
 #'
 #'
 #' @export
@@ -970,7 +980,7 @@ se.ave.cor.nonover <- function(cor12, cor34, cor13, cor14, cor23, cor24, n) {
   out2 <- t(c(est2, se2, v1.z, v2.z, cov2))
   out <- rbind(out1, out2)
   colnames(out) <- c("Estimate", "SE", "VAR(cor12)", "VAR(cor34)", "COV(cor12,cor34)")
-  rownames(out) <- c("Correlation", "Fisher")
+  rownames(out) <- c("Correlation: ", "Fisher: ")
   return(out)
 }
 
@@ -1004,7 +1014,7 @@ se.ave.cor.nonover <- function(cor12, cor34, cor13, cor14, cor23, cor24, n) {
 #'
 #' @return
 #' Returns a 1-row matrix. The columns are:
-#' * Estimate - estimate of tetrachoric approximation
+#' * Estimate - estimated tetrachoric approximation
 #' * SE - standard error
 #'
 #'
@@ -1012,8 +1022,8 @@ se.ave.cor.nonover <- function(cor12, cor34, cor13, cor14, cor23, cor24, n) {
 #' se.tetra(46, 15, 54, 85)
 #'
 #' # Should return:
-#' #       Estimate         SE 
-#' # [1,] 0.5135167 0.09358336
+#' #                Estimate         SE 
+#' # Tetrachoric:  0.5135167 0.09358336
 #'
 #'
 #' @export
@@ -1033,6 +1043,7 @@ se.tetra <- function(f00, f01, f10, f11) {
  se <- k*se.lor
  out <- t(c(tetra, se))
  colnames(out) <- c("Estimate", "SE")
+ rownames(out) <- "Tetrachoric: "
  return(out)
 }
 
@@ -1061,7 +1072,7 @@ se.tetra <- function(f00, f01, f10, f11) {
 #'
 #' @return
 #' Returns a 1-row matrix. The columns are:
-#' * Estimate - estimate of biserial-phi correlation 
+#' * Estimate - estimated biserial-phi correlation 
 #' * SE - standard error
 #'
 #'
@@ -1069,8 +1080,8 @@ se.tetra <- function(f00, f01, f10, f11) {
 #' se.biphi(34, 22, 50, 50)
 #'
 #' # Should return:
-#' #       Estimate        SE 
-#' # [1,]   0.27539 0.1074594
+#' #               Estimate        SE 
+#' # Biserial-phi:  0.27539 0.1074594
 #'
 #'
 #' @export
@@ -1091,6 +1102,54 @@ se.biphi <- function(f1, f2, n1, n2) {
  se.biphi <- sqrt(c^2/(lor^2 + c)^3)*se.lor
  out <- t(c(biphi, se.biphi))
  colnames(out) <- c("Estimate", "SE")
+ rownames(out) <- "Biserial-phi: "
  return(out)
 }
 
+
+# se.cohen ====================================================================		
+#' Computes the standard error for Cohen's d
+#' 
+#' 
+#' @description
+#' This function computes the standard error of Cohen's d using only the two 
+#' sample sizes and an estimate of Cohen's d. Cohen's d and its standard error 
+#' assume equal variances. The estimate of Cohen's d, with the standard error
+#' output from this function, can be used as input in the \link[vcmeta]{meta.ave.gen},
+#' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
+#' applications where different types of compatible standardized mean 
+#' differences are used in the meta-analysis. 
+#'
+#' 
+#' @param    d		  estimated Cohen's d
+#' @param    n1		  sample size for group 1
+#' @param    n2		  sample size for group 2
+#' 
+#' 
+#' @return
+#' Returns a one-row matrix:
+#' * Estimate - Cohen's d (from input)
+#' * SE - standard error
+#' 
+#' 
+#' @examples
+#' se.cohen(.78, 35, 50)
+#'
+#' # Should return: 
+#' #            Estimate        SE
+#' # Cohen's d:     0.78 0.2288236
+#'
+#'
+#' @seealso \link[vcmeta]{se.stdmean2}
+#'
+#'
+#' @export
+se.cohen <- function(d, n1, n2) {
+  df1 <- n1 - 1
+  df2 <- n2 - 1
+  se <- sqrt(d^2*(1/df1 + 1/df2)/8 + 1/n1 + 1/n2)
+  out <- t(c(d, se))
+  colnames(out) <- c("Estimate", "SE")
+  rownames(out) <- "Cohen's d: "
+  return(out)
+}
